==> apache-james-imap-0.1-source-release.zip: apache-james-imap-0.1/message/src/main/java/org/apache/james/imap/message/request/SearchRequest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.imap.message.request;

import org.apache.james.imap.api.ImapCommand;
import org.apache.james.imap.api.message.request.SearchKey;

public class SearchRequest extends AbstractImapRequest {

    private final SearchKey searchKey;

    private final boolean useUids;

    public SearchRequest(final ImapCommand command, final SearchKey SearchKey,
            final boolean useUids, final String tag) {
        super(tag, command);
        this.searchKey = SearchKey;
        this.useUids = useUids;
    }

    public final SearchKey getSearchKey() {
        return searchKey;
    }

    public final boolean isUseUids() {
        return useUids;
    }
}

==> apache-james-imap-0.2-source-release.zip: apache-james-imap-0.2/message/src/main/java/org/apache/james/imap/message/request/SearchRequest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.imap.message.request;

import org.apache.james.imap.api.ImapCommand;
import org.apache.james.imap.api.message.request.SearchKey;

public class SearchRequest extends AbstractImapRequest {

    private final SearchKey searchKey;

    private final boolean useUids;

    public SearchRequest(final ImapCommand command, final SearchKey SearchKey, final boolean useUids, final String tag) {
        super(tag, command);
        this.searchKey = SearchKey;
        this.useUids = useUids;
    }

    public final SearchKey getSearchKey() {
        return searchKey;
    }

    public final boolean isUseUids() {
        return useUids;
    }
}
